@@ -34,7 +34,7 @@ class DesignWidget : public QWidget
 {
   Q_OBJECT
 public:
-  DesignWidget(QWidget* parent = 0, Qt::WindowFlags f = 0);
+  DesignWidget(QWidget *parent = 0, Qt::WindowFlags f = 0);
 
   Grantlee::Context getContext();
 
@@ -45,8 +45,11 @@ Q_SIGNALS:
 
 private:
   void setInitialContent();
-  void insertProperty(int row, const QString &type, const QString &name, bool readonly);
-  void insertMethod(const QString &access, bool _virtual, const QString &type, const QString &name, bool _const, QList<QStringList> args = QList<QStringList>());
+  void insertProperty(int row, const QString &type, const QString &name,
+                      bool readonly);
+  void insertMethod(const QString &access, bool _virtual, const QString &type,
+                    const QString &name, bool _const,
+                    QList<QStringList> args = QList<QStringList>());
 
 private Q_SLOTS:
   void setArgsRootIndex(const QModelIndex &index);
