@@ -12,7 +12,10 @@ class LocalRequestManager : public QNetworkAccessManager
 public:
   LocalRequestManager(Grantlee::Engine *engine, QObject *parent = 0);
 
-  virtual QNetworkReply* createRequest(Operation op, const QNetworkRequest& request, QIODevice* outgoingData = 0);
+  virtual QNetworkReply *createRequest(Operation op,
+                                       const QNetworkRequest &request,
+                                       QIODevice *outgoingData = 0);
+
 private:
   Grantlee::Engine *m_engine;
 };
