@@ -84,20 +84,17 @@ QVariant timeSince(const QDateTime &early, const QDateTime &late)
   return firstChunk;
 }
 
-QVariant timeUntil(const QDateTime &dt, QDateTime now = QDateTime())
-{
-  if (!now.isValid())
-    now = QDateTime::currentDateTime();
-
-  return timeSince(now, dt);
-}
-
 QVariant DateFilter::doFilter(const QVariant &input, const QVariant &argument,
                               bool autoescape) const
 {
   Q_UNUSED(autoescape)
   auto d = QDateTime::fromString(getSafeString(input),
-                                 QStringLiteral("yyyy-MM-ddThh:mm:ss"));
+#if QT_VERSION < QT_VERSION_CHECK(5, 11, 0)
+                                 QStringLiteral("yyyy-MM-ddThh:mm:ss")
+#else
+                                 QStringLiteral("yyyy-MM-ddThh:mm:ss.zzz")
+#endif
+  );
 
   auto argString = getSafeString(argument);
 
@@ -128,7 +125,10 @@ QVariant TimeSinceFilter::doFilter(const QVariant &input,
   else
     late = argument.value<QDateTime>();
 
-  return timeSince(input.value<QDateTime>(), late);
+  auto early = input.value<QDateTime>();
+  if (!early.isValid())
+    return QVariant();
+  return timeSince(early, late);
 }
 
 QVariant TimeUntilFilter::doFilter(const QVariant &input,
@@ -142,5 +142,8 @@ QVariant TimeUntilFilter::doFilter(const QVariant &input,
   else
     early = argument.value<QDateTime>();
 
-  return timeSince(early, input.value<QDateTime>());
+  auto late = input.value<QDateTime>();
+  if (!late.isValid())
+    return QVariant();
+  return timeSince(early, late);
 }
