@@ -53,7 +53,7 @@ QVariant CapFirstFilter::doFilter(const QVariant &input,
 
   return QVariant(safeString.get().at(0).toUpper()
                   + static_cast<QString>(
-                        safeString.get().right(safeString.get().size() - 1)));
+                      safeString.get().right(safeString.get().size() - 1)));
 }
 
 EscapeJsFilter::EscapeJsFilter() {}
@@ -102,10 +102,7 @@ QVariant EscapeJsFilter::doFilter(const QVariant &input,
 
   static const auto jsEscapes = getJsEscapes();
 
-  QListIterator<QPair<QString, QString>> it(jsEscapes);
-
-  while (it.hasNext()) {
-    auto escape = it.next();
+  for (auto &escape : jsEscapes) {
     retString = retString.replace(escape.first, escape.second);
   }
   return retString;
@@ -352,6 +349,8 @@ QVariant WordWrapFilter::doFilter(const QVariant &input,
   QString _input = getSafeString(input);
   auto width = argument.value<int>();
   auto partList = _input.split(QLatin1Char(' '), QString::SkipEmptyParts);
+  if (partList.isEmpty())
+    return QVariant();
   auto output = partList.takeFirst();
   auto pos = output.size() - output.lastIndexOf(QLatin1Char('\n')) - 1;
   Q_FOREACH (const QString &part, partList) {
