@@ -24,7 +24,7 @@
 #include "exception.h"
 #include "grantlee_config_p.h"
 #include "grantlee_version.h"
-#ifdef QT_SCRIPT_LIB
+#ifdef QT_QML_LIB
 #include "scriptabletags.h"
 #endif
 #include "template_p.h"
@@ -52,7 +52,7 @@ Engine::Engine(QObject *parent)
 
 Engine::~Engine()
 {
-#ifdef QT_SCRIPT_LIB
+#ifdef QT_QML_LIB
   qDeleteAll(d_ptr->m_scriptableLibraries);
 #endif
   d_ptr->m_libraries.clear();
@@ -74,11 +74,9 @@ void Engine::addTemplateLoader(QSharedPointer<AbstractTemplateLoader> loader)
 QPair<QString, QString> Engine::mediaUri(const QString &fileName) const
 {
   Q_D(const Engine);
-  QListIterator<QSharedPointer<AbstractTemplateLoader>> it(d->m_loaders);
 
   QPair<QString, QString> uri;
-  while (it.hasNext()) {
-    const auto loader = it.next();
+  for (auto &loader : d->m_loaders) {
     uri = loader->getMediaUri(fileName);
     if (!uri.second.isEmpty())
       break;
@@ -142,7 +140,7 @@ void Engine::loadDefaultLibraries()
 {
   Q_D(Engine);
 
-#ifdef QT_SCRIPT_LIB
+#ifdef QT_QML_LIB
   // Make sure we can load default scriptable libraries if we're supposed to.
   if (d->m_defaultLibraries.contains(QLatin1String(__scriptableLibName))
       && !d->m_scriptableTagLibrary) {
@@ -169,40 +167,12 @@ void Engine::loadDefaultLibraries()
     if (d->m_libraries.contains(libName))
       continue;
 
-    // Warning. We load C++ plugins in this method, but not plugins written
-    // in
-    // QtScript.
-    // This should be a better situation in Grantlee 0.2 when the
-    // TagLibraryInterface
-    // can have shared pointers instead of raw pointers in its API. The
-    // whole
-    // scriptable
-    // thing likely needs to be redesigned too.
-    // The reason for explicitly not loading scripted plugins here is that
-    // they
-    // create new
-    // NodeFactory and Filter instances with each call to loadLibrary.
-    // NodeFactories are memory-managed by the Parser, as are Filters to an
-    // extent, because it
-    // creates shared pointers for Filters.
-    // Because this method loads the libraries but doesn't actually use them
-    // or
-    // send them
-    // back to the Parser the scriptable NodeFactories and Filters but be
-    // deleted immediately.
-    // The C++ plugins are different because although they are loaded, their
-    // NodeFactories
-    // and Filters are accessed only by the Parser, which manages them after
-    // that.
     uint minorVersion = GRANTLEE_VERSION_MINOR;
     while (acceptableVersion<GRANTLEE_MIN_PLUGIN_VERSION>(minorVersion)) {
-#ifdef QT_SCRIPT_LIB
+#ifdef QT_QML_LIB
       // Although we don't use scripted libaries here, we need to
-      // recognize them
-      // being first
-      // in the search path and not load a c++ plugin of the same name in
-      // that
-      // case.
+      // recognize them being first in the search path and not load a
+      // c++ plugin of the same name in that case.
       auto scriptableLibrary = d->loadScriptableLibrary(libName, minorVersion);
       if (scriptableLibrary) {
         scriptableLibrary->clear();
@@ -224,7 +194,7 @@ TagLibraryInterface *Engine::loadLibrary(const QString &name)
 {
   Q_D(Engine);
 
-#ifdef QT_SCRIPT_LIB
+#ifdef QT_QML_LIB
   if (name == QLatin1String(__scriptableLibName))
     return 0;
 #endif
@@ -251,7 +221,7 @@ TagLibraryInterface *Engine::loadLibrary(const QString &name)
 TagLibraryInterface *EnginePrivate::loadLibrary(const QString &name,
                                                 uint minorVersion)
 {
-#ifdef QT_SCRIPT_LIB
+#ifdef QT_QML_LIB
   auto scriptableLibrary = loadScriptableLibrary(name, minorVersion);
   if (scriptableLibrary)
     return scriptableLibrary;
@@ -264,7 +234,7 @@ TagLibraryInterface *EnginePrivate::loadLibrary(const QString &name,
 
 EnginePrivate::EnginePrivate(Engine *engine)
     : q_ptr(engine)
-#ifdef QT_SCRIPT_LIB
+#ifdef QT_QML_LIB
       ,
       m_scriptableTagLibrary(0)
 #endif
@@ -301,7 +271,7 @@ QString EnginePrivate::getScriptLibraryName(const QString &name,
   return QString();
 }
 
-#ifdef QT_SCRIPT_LIB
+#ifdef QT_QML_LIB
 ScriptableLibraryContainer *
 EnginePrivate::loadScriptableLibrary(const QString &name, uint minorVersion)
 {
@@ -389,10 +359,7 @@ Template Engine::loadByName(const QString &name) const
 {
   Q_D(const Engine);
 
-  QListIterator<QSharedPointer<AbstractTemplateLoader>> it(d->m_loaders);
-  while (it.hasNext()) {
-    const auto loader = it.next();
-
+  for (auto &loader : d->m_loaders) {
     if (!loader->canLoadTemplate(name))
       continue;
 
