@@ -48,7 +48,7 @@ public:
     Parses the template to create a Nodelist.
     The given @p parent is the parent of each node in the returned list.
   */
-  NodeList parse(QObject *parent, const QStringList &stopAt = QStringList());
+  NodeList parse(QObject *parent, const QStringList &stopAt);
 
   void openLibrary(TagLibraryInterface *library);
   Q_DECLARE_PUBLIC(Parser)
@@ -66,8 +66,6 @@ public:
 void ParserPrivate::openLibrary(TagLibraryInterface *library)
 {
   Q_Q(Parser);
-  QHashIterator<QString, AbstractNodeFactory *> nodeIt(
-      library->nodeFactories());
 
   auto ti = qobject_cast<TemplateImpl *>(q->parent());
 
@@ -75,14 +73,15 @@ void ParserPrivate::openLibrary(TagLibraryInterface *library)
   Q_ASSERT(cengine);
   auto engine = const_cast<Engine *>(cengine);
 
-  while (nodeIt.hasNext()) {
-    nodeIt.next();
+  auto factories = library->nodeFactories();
+  for (auto nodeIt = factories.begin(), nodeEnd = factories.end();
+       nodeIt != nodeEnd; ++nodeIt) {
     nodeIt.value()->setEngine(engine);
     m_nodeFactories.insert(nodeIt.key(), nodeIt.value());
   }
-  QHashIterator<QString, Filter *> filterIt(library->filters());
-  while (filterIt.hasNext()) {
-    filterIt.next();
+  auto filters = library->filters();
+  for (auto filterIt = filters.begin(), filterEnd = filters.end();
+       filterIt != filterEnd; ++filterIt) {
     auto f = QSharedPointer<Filter>(filterIt.value());
     m_filters.insert(filterIt.key(), f);
   }
@@ -166,7 +165,7 @@ QSharedPointer<Filter> Parser::getFilter(const QString &name) const
 NodeList Parser::parse(Node *parent, const QString &stopAt)
 {
   Q_D(Parser);
-  return d->parse(parent, QStringList() << stopAt);
+  return d->parse(parent, {stopAt});
 }
 
 NodeList Parser::parse(TemplateImpl *parent, const QStringList &stopAt)
@@ -205,7 +204,7 @@ NodeList ParserPrivate::parse(QObject *parent, const QStringList &stopAt)
       FilterExpression filterExpression;
       try {
         filterExpression = FilterExpression(token.content, q);
-      } catch (Grantlee::Exception e) {
+      } catch (const Grantlee::Exception &e) {
         throw Grantlee::Exception(e.errorCode(),
                                   QStringLiteral("%1, line %2, %3")
                                       .arg(e.what())
@@ -247,7 +246,7 @@ NodeList ParserPrivate::parse(QObject *parent, const QStringList &stopAt)
       Node *n;
       try {
         n = nodeFactory->getNode(token.content, q);
-      } catch (Grantlee::Exception e) {
+      } catch (const Grantlee::Exception &e) {
         throw Grantlee::Exception(e.errorCode(),
                                   QStringLiteral("%1, line %2, %3")
                                       .arg(e.what())
@@ -310,7 +309,8 @@ void Parser::invalidBlockTag(const Token &token, const QString &command,
   } else {
     throw Grantlee::Exception(
         InvalidBlockTagError,
-        QStringLiteral("Invalid block tag on line %1: '%2\''. Did you forget to register or load this tag?")
+        QStringLiteral("Invalid block tag on line %1: '%2\''. Did you forget "
+                       "to register or load this tag?")
             .arg(token.linenumber)
             .arg(command));
   }
