@@ -35,7 +35,7 @@ class ScriptableContext : public QObject
 {
   Q_OBJECT
 public:
-  explicit ScriptableContext(Context *c, QObject *parent = 0);
+  explicit ScriptableContext(Context *c, QObject *parent = {});
 
   Context *context() { return m_c; }
 
@@ -45,7 +45,7 @@ public Q_SLOTS:
   void push();
   void pop();
 
-  QString render(const QObjectList &list) const;
+  QString render(const QList<QObject *> &list) const;
 
 private:
   Context *m_c;
