@@ -22,21 +22,16 @@
 #define SCRIPTABLE_SAFESTRING
 
 #include <QtCore/QObject>
-#include <QtScript/QScriptValue>
 
 #include "safestring.h"
 
-class QScriptContext;
-
 using namespace Grantlee;
 
-QScriptValue markSafeFunction(QScriptContext *context, QScriptEngine *engine);
-
 class ScriptableSafeString : public QObject
 {
   Q_OBJECT
 public:
-  ScriptableSafeString(QObject *parent = 0);
+  ScriptableSafeString(QObject *parent = {});
 
   void setContent(const SafeString &content);
   SafeString wrappedString() const;
