@@ -22,25 +22,19 @@
 #define SCRIPTABLE_VARIABLE_H
 
 #include <QtCore/QObject>
-#include <QtScript/QScriptValue>
+#include <QtQml/QJSValue>
 
+#include "scriptablecontext.h"
 #include "variable.h"
 
-class QScriptContext;
-
-class ScriptableContext;
-
 using namespace Grantlee;
 
-QScriptValue ScriptableVariableConstructor(QScriptContext *context,
-                                           QScriptEngine *engine);
-
 class ScriptableVariable : public QObject
 {
   Q_OBJECT
 public:
-  ScriptableVariable(QObject *parent = 0);
-  ScriptableVariable(QScriptEngine *engine, QObject *parent = 0);
+  ScriptableVariable(QObject *parent = {});
+  ScriptableVariable(QJSEngine *engine, QObject *parent = {});
 
   void setContent(const QString &content);
 
@@ -51,7 +45,7 @@ public Q_SLOTS:
 
 private:
   Variable m_variable;
-  QScriptEngine *m_engine;
+  QJSEngine *m_engine;
 };
 
 #endif
