@@ -1,29 +1,25 @@
 #include "coverageobject.h"
-#include <QTest>
-#include <QMetaObject>
-#include <QDir>
-#include <QString>
 #include <QDebug>
-#include <QtDebug>
+#include <QDir>
 #include <QLibrary>
+#include <QMetaObject>
+#include <QString>
+#include <QTest>
+#include <QtDebug>
 
 #include "grantlee_paths.h"
 
-void CoverageObject::init()
-{
-  initTest();
-}
+void CoverageObject::init() { initTest(); }
 
 QString CoverageObject::generateTestName() const
 {
   QString test_name;
-  test_name+=QString::fromLatin1(metaObject()->className());
-  test_name+=QString::fromLatin1("/");
-  test_name+=QString::fromLatin1(QTest::currentTestFunction());
-  if (QTest::currentDataTag())
-  {
-    test_name+=QString::fromLatin1("/");
-    test_name+=QString::fromLatin1(QTest::currentDataTag());
+  test_name += QString::fromLatin1(metaObject()->className());
+  test_name += QLatin1String("/");
+  test_name += QString::fromLatin1(QTest::currentTestFunction());
+  if (QTest::currentDataTag()) {
+    test_name += QLatin1String("/");
+    test_name += QString::fromLatin1(QTest::currentDataTag());
   }
   return test_name;
 }
@@ -38,7 +34,7 @@ void CoverageObject::saveCoverageData()
   if (QTest::currentTestFailed())
     __coveragescanner_teststate("FAILED");
   else
-    __coveragescanner_teststate("PASSED") ;
+    __coveragescanner_teststate("PASSED");
   __coveragescanner_save();
   __coveragescanner_testname("");
   __coveragescanner_clear();
@@ -50,5 +46,3 @@ void CoverageObject::cleanup()
   cleanupTest();
   saveCoverageData();
 }
-
-#include "coverageobject.moc"
