@@ -36,7 +36,7 @@ class TestGenericContainers : public CoverageObject
 {
   Q_OBJECT
 public:
-  explicit TestGenericContainers(QObject *parent = 0);
+  explicit TestGenericContainers(QObject *parent = {});
 
 private Q_SLOTS:
   void testContainer_Builtins();
@@ -151,46 +151,53 @@ template <typename T> struct ContainerPopulator<std::map<QString, T>> {
 
 template <typename T> QString getTemplate()
 {
-  return QStringLiteral("{{ container.size }};{{ container.count }};{% for item in container %}{{ item }},{% endfor %}");
+  return QStringLiteral("{{ container.size }};{{ container.count }};{% for "
+                        "item in container %}{{ item }},{% endfor %}");
 }
 
 template <> QString getTemplate<QDateTime>()
 {
-  return QStringLiteral("{{ container.size }};{{ container.count }};{% for item in container %}{{ item|date }},{% endfor %}");
+  return QStringLiteral("{{ container.size }};{{ container.count }};{% for "
+                        "item in container %}{{ item|date }},{% endfor %}");
 }
 
 template <> QString getTemplate<QObject *>()
 {
-  return QStringLiteral("{{ container.size }};{{ container.count }};{% for item in container %}{{ item.objectName }},{% endfor %}");
+  return QStringLiteral(
+      "{{ container.size }};{{ container.count }};{% for item in container "
+      "%}{{ item.objectName }},{% endfor %}");
 }
 
 template <typename T> QString getAssociativeTemplate()
 {
-  return QStringLiteral("{{ container.size }};{{ container.count }};{% for item in container.values %}{{ item }},{% endfor %}");
+  return QStringLiteral("{{ container.size }};{{ container.count }};{% for "
+                        "item in container.values %}{{ item }},{% endfor %}");
 }
 
 template <> QString getAssociativeTemplate<QDateTime>()
 {
-  return QStringLiteral("{{ container.size }};{{ container.count }};{% for item in container.values %}{{ item|date }},{% endfor %}");
+  return QStringLiteral(
+      "{{ container.size }};{{ container.count }};{% for item in "
+      "container.values %}{{ item|date }},{% endfor %}");
 }
 
 template <> QString getAssociativeTemplate<QObject *>()
 {
-  return QStringLiteral("{{ container.size }};{{ container.count }};{% for item in container.values %}{{ item.objectName }},{% endfor %}");
+  return QStringLiteral(
+      "{{ container.size }};{{ container.count }};{% for item in "
+      "container.values %}{{ item.objectName }},{% endfor %}");
 }
 
 template <typename T> QStringList getResults()
 {
-  return QStringList() << QStringLiteral("3;3;") << QStringLiteral("9,")
-                       << QStringLiteral("7,") << QStringLiteral("5,");
+  return {QStringLiteral("3;3;"), QStringLiteral("9,"), QStringLiteral("7,"),
+          QStringLiteral("5,")};
 }
 
 template <> QStringList getResults<QDateTime>()
 {
-  return QStringList() << QStringLiteral("3;3;")
-                       << QStringLiteral("Jan. 1, 1970,")
-                       << QStringLiteral("Jan. 2, 1970,")
-                       << QStringLiteral("Jan. 3, 1970,");
+  return {QStringLiteral("3;3;"), QStringLiteral("Jan. 1, 1970,"),
+          QStringLiteral("Jan. 2, 1970,"), QStringLiteral("Jan. 3, 1970,")};
 }
 
 template <typename Container, typename T = typename Container::value_type>
@@ -242,7 +249,7 @@ void testContainer(const QString &stringTemplate,
 {
   Grantlee::Engine engine;
 
-  engine.setPluginPaths(QStringList() << QStringLiteral(GRANTLEE_PLUGIN_PATH));
+  engine.setPluginPaths({QStringLiteral(GRANTLEE_PLUGIN_PATH)});
 
   Grantlee::Context c;
   c.insert(QStringLiteral("container"), containerVariant);
@@ -267,7 +274,7 @@ void testContainer(const QString &stringTemplate,
 }
 
 template <typename Container>
-void doTestSequentialContainer(bool unordered = false)
+void doTestSequentialContainer(bool unordered = {})
 {
   Container container;
   ContainerPopulator<Container>::populateSequential(container);
@@ -279,7 +286,7 @@ void doTestSequentialContainer(bool unordered = false)
 }
 
 template <typename Container>
-void doTestAssociativeContainer(bool unordered = false)
+void doTestAssociativeContainer(bool unordered = {})
 {
   Container container;
   ContainerPopulator<Container>::populateAssociative(container);
