@@ -37,20 +37,13 @@
 #include <deque>
 #include <string>
 
-#ifndef GRANTLEE_NO_TR1
-
-#ifdef Q_CC_MSVC
 #include <memory>
-#else
-#include <tr1/memory>
-#endif
 
 Q_DECLARE_SEQUENTIAL_CONTAINER_METATYPE(ThreeArray)
 
 Q_DECLARE_ASSOCIATIVE_CONTAINER_METATYPE(QtUnorderedMap)
 
-Q_DECLARE_SMART_POINTER_METATYPE(std::tr1::shared_ptr)
-#endif
+Q_DECLARE_SMART_POINTER_METATYPE(std::shared_ptr)
 
 Q_DECLARE_SEQUENTIAL_CONTAINER_METATYPE(std::deque)
 
@@ -73,8 +66,13 @@ private Q_SLOTS:
 
   void testCustomQObjectDerived();
 
+  void propertyMacroTypes();
+
   void testUnregistered();
   void testPointerNonQObject();
+  void testQGadget();
+  void testGadgetMetaType();
+
 }; // class TestGenericTypes
 
 class Person
@@ -94,9 +92,19 @@ public:
   int uid;
 };
 
+class PersonGadget
+{
+  Q_GADGET
+  Q_PROPERTY(QString name MEMBER m_name)
+public:
+  QString m_name;
+  int m_age = 42;
+};
+
 int qHash(const Person &p) { return p.uid; }
 
 Q_DECLARE_METATYPE(Person)
+Q_DECLARE_METATYPE(PersonGadget)
 
 GRANTLEE_BEGIN_LOOKUP(Person)
 if (property == QStringLiteral("name"))
@@ -105,13 +113,18 @@ else if (property == QStringLiteral("age"))
   return object.age;
 GRANTLEE_END_LOOKUP
 
+GRANTLEE_BEGIN_LOOKUP(PersonGadget)
+if (property == QStringLiteral("age"))
+  return object.m_age;
+GRANTLEE_END_LOOKUP
+
 class PersonObject : public QObject
 {
   Q_OBJECT
   Q_PROPERTY(QString name READ name)
   Q_PROPERTY(int age READ age)
 public:
-  PersonObject(const QString &name, int age, QObject *parent = 0)
+  PersonObject(const QString &name, int age, QObject *parent = {})
       : QObject(parent), m_name(name), m_age(age)
   {
   }
@@ -128,13 +141,14 @@ void TestGenericTypes::initTestCase()
 {
   // Register the handler for our custom type
   Grantlee::registerMetaType<Person>();
+  Grantlee::registerMetaType<PersonGadget>();
 }
 
 void TestGenericTypes::testGenericClassType()
 {
   Grantlee::Engine engine;
 
-  engine.setPluginPaths(QStringList() << QStringLiteral(GRANTLEE_PLUGIN_PATH));
+  engine.setPluginPaths({QStringLiteral(GRANTLEE_PLUGIN_PATH)});
 
   auto t1 = engine.newTemplate(
       QStringLiteral(
@@ -200,7 +214,7 @@ template <typename Container> void testSequentialIteration(Grantlee::Context &c)
 {
   Grantlee::Engine engine;
 
-  engine.setPluginPaths(QStringList() << QStringLiteral(GRANTLEE_PLUGIN_PATH));
+  engine.setPluginPaths({QStringLiteral(GRANTLEE_PLUGIN_PATH)});
 
   {
     Grantlee::Template t1 = engine.newTemplate(
@@ -215,7 +229,7 @@ template <typename Container> void testSequentialIndexing(Grantlee::Context &c)
 {
   Grantlee::Engine engine;
 
-  engine.setPluginPaths(QStringList() << QStringLiteral(GRANTLEE_PLUGIN_PATH));
+  engine.setPluginPaths({QStringLiteral(GRANTLEE_PLUGIN_PATH)});
 
   {
     Grantlee::Template t1 = engine.newTemplate(
@@ -243,17 +257,15 @@ template <typename T> struct SequentialContainerTester<QSet<T>> {
   {
     Grantlee::Engine engine;
 
-    engine.setPluginPaths(QStringList()
-                          << QStringLiteral(GRANTLEE_PLUGIN_PATH));
+    engine.setPluginPaths({QStringLiteral(GRANTLEE_PLUGIN_PATH)});
 
     Grantlee::Template t1 = engine.newTemplate(
         QStringLiteral(
             "{% for person in people %}{{ person.name }},{% endfor %}"),
         QStringLiteral("people_template"));
     auto result = t1->render(&c);
-    QStringList output;
-    output << QStringLiteral("Claire,") << QStringLiteral("Grant,")
-           << QStringLiteral("Alan,");
+    QStringList output{QStringLiteral("Claire,"), QStringLiteral("Grant,"),
+                       QStringLiteral("Alan,")};
     Q_FOREACH (const QString &s, output) {
       QVERIFY(result.contains(s));
     }
@@ -293,15 +305,16 @@ template <typename Container> void doTestSequentialContainer_Variant()
 }
 
 template <typename Container>
-void testAssociativeValues(Grantlee::Context &c, bool unordered = false)
+void testAssociativeValues(Grantlee::Context &c, bool unordered = {})
 {
   Grantlee::Engine engine;
 
-  engine.setPluginPaths(QStringList() << QStringLiteral(GRANTLEE_PLUGIN_PATH));
+  engine.setPluginPaths({QStringLiteral(GRANTLEE_PLUGIN_PATH)});
 
   {
     Grantlee::Template t1 = engine.newTemplate(
-        QStringLiteral("{% for person in people.values %}({{ person.name }}:{{ person.age }}),{% endfor %}"),
+        QStringLiteral("{% for person in people.values %}({{ person.name }}:{{ "
+                       "person.age }}),{% endfor %}"),
         QStringLiteral("people_template"));
 
     auto result = t1->render(&c);
@@ -321,11 +334,12 @@ void testAssociativeItems(Grantlee::Context &c, bool unordered)
 {
   Grantlee::Engine engine;
 
-  engine.setPluginPaths(QStringList() << QStringLiteral(GRANTLEE_PLUGIN_PATH));
+  engine.setPluginPaths({QStringLiteral(GRANTLEE_PLUGIN_PATH)});
 
   {
     Grantlee::Template t1 = engine.newTemplate(
-        QStringLiteral("{% for item in people.items %}({{ item.1.name }}:{{ item.1.age }}),{% endfor %}"),
+        QStringLiteral("{% for item in people.items %}({{ item.1.name }}:{{ "
+                       "item.1.age }}),{% endfor %}"),
         QStringLiteral("people_template"));
     auto result = t1->render(&c);
     if (!unordered)
@@ -340,11 +354,11 @@ void testAssociativeItems(Grantlee::Context &c, bool unordered)
 }
 
 template <typename Container>
-void doTestAssociativeContainer_Variant(bool unordered = false)
+void doTestAssociativeContainer_Variant(bool unordered = {})
 {
   Grantlee::Engine engine;
 
-  engine.setPluginPaths(QStringList() << QStringLiteral(GRANTLEE_PLUGIN_PATH));
+  engine.setPluginPaths({QStringLiteral(GRANTLEE_PLUGIN_PATH)});
 
   Grantlee::Context c;
 
@@ -390,7 +404,6 @@ template <> void insertPeople<QSet<Person>>(Grantlee::Context &c)
   c.insert(QStringLiteral("people"), QVariant::fromValue(container));
 }
 
-#ifndef GRANTLEE_NO_TR1
 template <> void insertPeople<ThreeArray<Person>>(Grantlee::Context &c)
 {
   auto people = getPeople();
@@ -402,7 +415,6 @@ template <> void insertPeople<ThreeArray<Person>>(Grantlee::Context &c)
   }
   c.insert(QStringLiteral("people"), QVariant::fromValue(container));
 }
-#endif
 
 template <typename AssociativeContainer>
 void insertAssociatedPeople(Grantlee::Context &c)
@@ -439,11 +451,11 @@ template <typename Container> void doTestSequentialContainer_Type()
 }
 
 template <typename Container>
-void doTestAssociativeContainer_Type(bool unordered = false)
+void doTestAssociativeContainer_Type(bool unordered = {})
 {
   Grantlee::Engine engine;
 
-  engine.setPluginPaths(QStringList() << QStringLiteral(GRANTLEE_PLUGIN_PATH));
+  engine.setPluginPaths({QStringLiteral(GRANTLEE_PLUGIN_PATH)});
 
   Grantlee::Context c;
 
@@ -453,11 +465,11 @@ void doTestAssociativeContainer_Type(bool unordered = false)
 }
 
 template <typename Container>
-void doTestAssociativeContainer_Type_Number(bool unordered = false)
+void doTestAssociativeContainer_Type_Number(bool unordered = {})
 {
   Grantlee::Engine engine;
 
-  engine.setPluginPaths(QStringList() << QStringLiteral(GRANTLEE_PLUGIN_PATH));
+  engine.setPluginPaths({QStringLiteral(GRANTLEE_PLUGIN_PATH)});
 
   Grantlee::Context c;
 
@@ -485,9 +497,7 @@ void TestGenericTypes::testSequentialContainer_Type()
   doTestSequentialContainer_Type<std::deque<Person>>();
   doTestSequentialContainer_Type<std::vector<Person>>();
   doTestSequentialContainer_Type<std::list<Person>>();
-#ifndef GRANTLEE_NO_TR1
   doTestSequentialContainer_Type<ThreeArray<Person>>();
-#endif
 }
 
 void TestGenericTypes::testAssociativeContainer_Type()
@@ -515,7 +525,6 @@ void TestGenericTypes::testAssociativeContainer_Type()
   doTestAssociativeContainer_Type_Number<std::map<quint32, Person>>();
   doTestAssociativeContainer_Type_Number<std::map<quint64, Person>>();
 
-#ifndef GRANTLEE_NO_TR1
   doTestAssociativeContainer_Type<QtUnorderedMap<QString, Person>>(true);
   doTestAssociativeContainer_Type_Number<QtUnorderedMap<qint16, Person>>(true);
   doTestAssociativeContainer_Type_Number<QtUnorderedMap<qint32, Person>>(true);
@@ -523,14 +532,13 @@ void TestGenericTypes::testAssociativeContainer_Type()
   doTestAssociativeContainer_Type_Number<QtUnorderedMap<quint16, Person>>(true);
   doTestAssociativeContainer_Type_Number<QtUnorderedMap<quint32, Person>>(true);
   doTestAssociativeContainer_Type_Number<QtUnorderedMap<quint64, Person>>(true);
-#endif
 }
 
 void TestGenericTypes::testSharedPointer()
 {
   Grantlee::Engine engine;
 
-  engine.setPluginPaths(QStringList() << QStringLiteral(GRANTLEE_PLUGIN_PATH));
+  engine.setPluginPaths({QStringLiteral(GRANTLEE_PLUGIN_PATH)});
 
   auto t1 = engine.newTemplate(QStringLiteral("{{ p.name }} {{ p.age }}"),
                                QStringLiteral("template1"));
@@ -546,22 +554,20 @@ void TestGenericTypes::testSharedPointer()
 
 void TestGenericTypes::testThirdPartySharedPointer()
 {
-#ifndef GRANTLEE_NO_TR1
   Grantlee::Engine engine;
 
-  engine.setPluginPaths(QStringList() << QStringLiteral(GRANTLEE_PLUGIN_PATH));
+  engine.setPluginPaths({QStringLiteral(GRANTLEE_PLUGIN_PATH)});
 
   auto t1 = engine.newTemplate(QStringLiteral("{{ p.name }} {{ p.age }}"),
                                QStringLiteral("template1"));
 
   // Check it
   QVariantHash h;
-  std::tr1::shared_ptr<PersonObject> p(
+  std::shared_ptr<PersonObject> p(
       new PersonObject(QStringLiteral("Grant Lee"), 2));
   h.insert(QStringLiteral("p"), QVariant::fromValue(p));
   Grantlee::Context c(h);
   QCOMPARE(t1->render(&c), QStringLiteral("Grant Lee 2"));
-#endif
 }
 
 typedef QList<QVector<qint16>> ListVectorInt;
@@ -608,7 +614,7 @@ void TestGenericTypes::testNestedContainers()
 {
   Grantlee::Engine engine;
 
-  engine.setPluginPaths(QStringList() << QStringLiteral(GRANTLEE_PLUGIN_PATH));
+  engine.setPluginPaths({QStringLiteral(GRANTLEE_PLUGIN_PATH)});
 
   Grantlee::Context c;
   c.insert(QStringLiteral("stack"), QVariant::fromValue(getMapStack()));
@@ -636,7 +642,9 @@ void TestGenericTypes::testNestedContainers()
 
   auto result = t1->render(&c);
 
-  auto expectedResult = QStringLiteral("(M (0 : (L (V 1,2,),(V 3,4,),),(1 : (L (V 5,6,),(V 7,8,),),),(M (0 : (L (V 9,10,),(V 11,12,),),(1 : (L (V 13,14,),(V 15,16,),),),");
+  auto expectedResult = QStringLiteral(
+      "(M (0 : (L (V 1,2,),(V 3,4,),),(1 : (L (V 5,6,),(V 7,8,),),),(M (0 : (L "
+      "(V 9,10,),(V 11,12,),),(1 : (L (V 13,14,),(V 15,16,),),),");
 
   QCOMPARE(result, expectedResult);
 }
@@ -645,7 +653,7 @@ class CustomObject : public QObject
 {
   Q_OBJECT
 public:
-  explicit CustomObject(QObject *parent = 0) : QObject(parent) {}
+  explicit CustomObject(QObject *parent = {}) : QObject(parent) {}
 };
 
 class OtherObject : public QObject
@@ -653,7 +661,7 @@ class OtherObject : public QObject
   Q_OBJECT
   Q_PROPERTY(CustomObject *custom READ custom)
 public:
-  explicit OtherObject(QObject *parent = 0)
+  explicit OtherObject(QObject *parent = {})
       : QObject(parent), m_custom(new CustomObject(this))
   {
     m_custom->setProperty("nestedProp", QStringLiteral("nestedValue"));
@@ -669,7 +677,7 @@ void TestGenericTypes::testCustomQObjectDerived()
 {
   Grantlee::Engine engine;
 
-  engine.setPluginPaths(QStringList() << QStringLiteral(GRANTLEE_PLUGIN_PATH));
+  engine.setPluginPaths({QStringLiteral(GRANTLEE_PLUGIN_PATH)});
 
   auto customObject = new CustomObject(this);
   customObject->setProperty("someProp", QStringLiteral("propValue"));
@@ -719,10 +727,7 @@ if (property == QStringLiteral("property"))
   return 42;
 GRANTLEE_END_LOOKUP
 
-static QVariantList dummy(const UnregisteredType &)
-{
-  return QVariantList() << 42;
-}
+static QVariantList dummy(const UnregisteredType &) { return QVariantList{42}; }
 
 QVariant dummyLookup(const QVariant &, const QString &) { return 42; }
 
@@ -785,5 +790,142 @@ void TestGenericTypes::testPointerNonQObject()
   delete p;
 }
 
+class CustomGadget
+{
+  Q_GADGET
+  Q_PROPERTY(int fortyTwo READ fortyTwo)
+public:
+  int fortyTwo() { return 42; }
+};
+
+void TestGenericTypes::testQGadget()
+{
+  CustomGadget g;
+  auto v = QVariant::fromValue(g);
+
+  auto result = Grantlee::MetaType::lookup(v, QStringLiteral("fortyTwo"));
+
+  QCOMPARE(result.value<int>(), 42);
+}
+
+void TestGenericTypes::testGadgetMetaType()
+{
+  Grantlee::Engine engine;
+  engine.setPluginPaths({QStringLiteral(GRANTLEE_PLUGIN_PATH)});
+
+  auto t1 = engine.newTemplate(
+      QStringLiteral("Person: \nName: {{p.name}}\nAge: {{p.age}}"),
+      QStringLiteral("template1"));
+
+  PersonGadget p;
+  p.m_name = QStringLiteral("Some Name");
+  Grantlee::Context c;
+  c.insert(QStringLiteral("p"), QVariant::fromValue(p));
+  QCOMPARE(t1->render(&c),
+           QStringLiteral("Person: \nName: Some Name\nAge: 42"));
+}
+
+class ObjectWithProperties : public QObject
+{
+  Q_OBJECT
+  Q_PROPERTY(QList<int> numberList READ numberList)
+  Q_PROPERTY(QList<CustomGadget> gadgetList READ gadgetList)
+  Q_PROPERTY(QVector<PersonObject *> personList READ personList)
+  Q_PROPERTY(
+      QVector<QSharedPointer<PersonObject>> personPtrList READ personPtrList)
+
+public:
+  ObjectWithProperties(QObject *parent = {}) : QObject(parent)
+  {
+    m_numberList.push_back(42);
+    m_numberList.push_back(7);
+    m_gadgetList.push_back(CustomGadget{});
+    m_gadgetList.push_back(CustomGadget{});
+    m_personList.push_back(new PersonObject{QStringLiteral("Joe"), 20});
+    m_personList.push_back(new PersonObject{QStringLiteral("Mike"), 22});
+    m_personPtrList.push_back(
+        QSharedPointer<PersonObject>::create(QStringLiteral("Niall"), 23));
+    m_personPtrList.push_back(
+        QSharedPointer<PersonObject>::create(QStringLiteral("Dave"), 24));
+  }
+
+  QList<int> numberList() { return m_numberList; }
+  QList<CustomGadget> gadgetList() { return m_gadgetList; }
+  QVector<PersonObject *> personList() { return m_personList; }
+  QVector<QSharedPointer<PersonObject>> personPtrList()
+  {
+    return m_personPtrList;
+  }
+
+private:
+  QList<int> m_numberList;
+  QList<CustomGadget> m_gadgetList;
+  QVector<PersonObject *> m_personList;
+  QVector<QSharedPointer<PersonObject>> m_personPtrList;
+};
+
+void TestGenericTypes::propertyMacroTypes()
+{
+  Grantlee::Engine engine;
+
+  qRegisterMetaType<QList<CustomGadget>>();
+
+  engine.setPluginPaths({QStringLiteral(GRANTLEE_PLUGIN_PATH)});
+
+  auto objectWithProperties = new ObjectWithProperties(this);
+
+  Grantlee::Context c;
+  c.insert(QStringLiteral("obj"), objectWithProperties);
+
+  {
+    auto t1 = engine.newTemplate(
+        QStringLiteral("{{ obj.numberList.0 }}--{{ obj.numberList.1 }}"),
+        QStringLiteral("template1"));
+
+    auto result = t1->render(&c);
+    auto expectedResult = QStringLiteral("42--7");
+
+    QCOMPARE(result, expectedResult);
+  }
+
+  {
+    auto t1 = engine.newTemplate(
+        QStringLiteral(
+            "{{ obj.gadgetList.0.fortyTwo }}--{{ obj.gadgetList.1.fortyTwo }}"),
+        QStringLiteral("template1"));
+
+    auto result = t1->render(&c);
+    auto expectedResult = QStringLiteral("42--42");
+
+    QCOMPARE(result, expectedResult);
+  }
+
+  {
+    auto t1 = engine.newTemplate(
+        QStringLiteral(
+            "{{ obj.personList.0.name }}({{ obj.personList.0.age }})"
+            "--{{ obj.personList.1.name }}({{ obj.personList.1.age }})"),
+        QStringLiteral("template1"));
+
+    auto result = t1->render(&c);
+    auto expectedResult = QStringLiteral("Joe(20)--Mike(22)");
+
+    QCOMPARE(result, expectedResult);
+  }
+
+  {
+    auto t1 = engine.newTemplate(
+        QStringLiteral(
+            "{{ obj.personPtrList.0.name }}({{ obj.personPtrList.0.age }})"
+            "--{{ obj.personPtrList.1.name }}({{ obj.personPtrList.1.age }})"),
+        QStringLiteral("template1"));
+
+    auto result = t1->render(&c);
+    auto expectedResult = QStringLiteral("Niall(23)--Dave(24)");
+
+    QCOMPARE(result, expectedResult);
+  }
+}
+
 QTEST_MAIN(TestGenericTypes)
 #include "testgenerictypes.moc"
